A lightweight ``PostgREST`` proxy that does not get in your way.

Installing
==========

.. code-block:: bash

  pip3 install aiodata

Links
-----

- `Documentation <https://aiodata.readthedocs.io>`_

.. warning::

  Versions bellow ``3.0.0`` are not guaranteed to work due to dependency changes.
